abacusai.eda_feature_association — AbacusAI documentation

# abacusai.eda_feature_association

## Classes

`EdaFeatureAssociation` | Eda Feature Association between two features in the data.

## Module Contents

class abacusai.eda_feature_association.EdaFeatureAssociation(client, data=None, isScatter=None, isBoxWhisker=None, xAxis=None, yAxis=None, xAxisColumnValues=None, yAxisColumnValues=None, dataColumns=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Eda Feature Association between two features in the data.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - data (dict) – the data to display the feature association between two features

    - isScatter (bool) – A Boolean that represents if the data creates a scatter plot (for cases of numerical data vs numerical data)

    - isBoxWhisker (bool) – A Boolean that represents if the data creates a box whisker plot (For cases of categorical data vs numerical data and vice versa)

    - xAxis (str) – Name of the feature selected for feature association (reference_feature_name) for x axis on the plot

    - yAxis (str) – Name of the feature selected for feature association (test_feature_name) for y axis on the plot

    - xAxisColumnValues (list) – Name of all the categories within the x_axis feature (if it is a categorical data type)

    - yAxisColumnValues (list) – Name of all the categories within the y_axis feature (if it is a categorical data type)

    - dataColumns (list) – A list of columns listed in the data as keys

  data = None
  is_scatter = None
  is_box_whisker = None
  x_axis = None
  y_axis = None
  x_axis_column_values = None
  y_axis_column_values = None
  data_columns = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict